#!/usr/bin/python

from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.am2cm_commons.cdp_cluster import CDPCluster
import json


def run_module():
    module_args = dict(
        cm_configuration=dict(type='dict', required=True)
    )

    result = dict(
        changed=False,
        original_message='',
        message=''
    )

    module = AnsibleModule(
        argument_spec=module_args,
        supports_check_mode=True
    )
    result['original_message'] = json.dumps(module.params)

    if module.check_mode:
        result['changed'] = True
        result['message'] = "Client configurations will be deployed to cluster " \
                            f"{module.params['cm_configuration']['cluster_name']}"
        module.exit_json(**result)
    # ####################################################################
    # ####################################################################
    cluster = CDPCluster(
        hostname=module.params['cm_configuration']['cloudera_manager_hostname'],
        port=module.params['cm_configuration']['cloudera_manager_port'],
        is_https=(module.params['cm_configuration']['cloudera_manager_protocol'] == 'https'),
        verify_ssl=False,
        username=module.params['cm_configuration']['cloudera_manager_admin_username'],
        password=module.params['cm_configuration']['cloudera_manager_admin_password'],
        cluster_name=module.params['cm_configuration']['cluster_name'])

    result['changed'], result['message'] = cluster.deploy_client_configs_and_refresh()

    module.exit_json(**result) if result['changed'] else module.fail_json(
        msg=f'Could not deploy client configurations', **result)


def main():
    run_module()


if __name__ == '__main__':
    main()
